@@ -5,8 +5,8 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2022
-;; Package-Version: 20251017.1515
-;; Package-Revision: 7641bf620bf2
+;; Package-Version: 20251116.1456
+;; Package-Revision: 21d3f00d1de7
 ;; Package-Requires: ((emacs "29.1") (compat "30"))
 ;; URL: https://github.com/minad/osm
 ;; Keywords: network, multimedia, hypermedia, mouse
@@ -894,7 +894,8 @@ Local per buffer since the overlays depend on the zoom level.")
               mwheel-scroll-left-function #'osm--zoom-out-wheel
               mwheel-scroll-right-function #'osm--zoom-in-wheel
               bookmark-make-record-function #'osm--bookmark-record-default
-              imenu-create-index-function #'osm--imenu-index)
+              imenu-create-index-function #'osm--imenu-index
+              mouse-shift-adjust-mode nil)
   (when (boundp 'mwheel-coalesce-scroll-events)
     (setq-local mwheel-coalesce-scroll-events t))
   (when (boundp 'pixel-scroll-precision-mode)
